==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/tags/ArrayCheckTag.h <==
// public class soot.jimple.toolkits.annotation.tags.ArrayCheckTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class afc01e7a340766a0 soot_jimple_toolkits_annotation_tags_ArrayCheckTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_tags_ArrayCheckTag_H_
#define _JC_soot_jimple_toolkits_annotation_tags_ArrayCheckTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_refs	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$refs	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$nonrefs	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object;

typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$fields_struct	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vmethods	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtable	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$fields_struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$_init$668f2a347f627c06(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *, jboolean, jboolean);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);
extern _jc_byte_array *_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);
extern jboolean _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$isCheckLower$258db8e5299b4d0e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);
extern jboolean _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$isCheckUpper$6f66fdbb960f2156(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$isCheckLower$258db8e5299b4d0e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$isCheckUpper$6f66fdbb960f2156;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);
	jboolean	(*isCheckLower$258db8e5299b4d0e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);
	jboolean	(*isCheckUpper$6f66fdbb960f2156)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vmethods	soot_jimple_toolkits_annotation_tags_ArrayCheckTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$refs {
    _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_refs	soot_jimple_toolkits_annotation_tags_ArrayCheckTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_nonrefs {
	jboolean	lowerCheck;
	jboolean	upperCheck;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_nonrefs	soot_jimple_toolkits_annotation_tags_ArrayCheckTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object {
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_tags_ArrayCheckTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_tags_ArrayCheckTag_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/tags/ArrayCheckTag.h <==
// public class soot.jimple.toolkits.annotation.tags.ArrayCheckTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class afc01e7a340766a0 soot_jimple_toolkits_annotation_tags_ArrayCheckTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_tags_ArrayCheckTag_H_
#define _JC_soot_jimple_toolkits_annotation_tags_ArrayCheckTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_refs	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$refs	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$nonrefs	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object;

typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$fields_struct	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vmethods	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtable	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$fields_struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$_init$668f2a347f627c06(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *, jboolean, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$isCheckLower$258db8e5299b4d0e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$isCheckUpper$6f66fdbb960f2156(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$isCheckLower$258db8e5299b4d0e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$isCheckUpper$6f66fdbb960f2156;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;
	jboolean	(*isCheckLower$258db8e5299b4d0e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;
	jboolean	(*isCheckUpper$6f66fdbb960f2156)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vmethods	soot_jimple_toolkits_annotation_tags_ArrayCheckTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$refs {
    _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_refs	soot_jimple_toolkits_annotation_tags_ArrayCheckTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_nonrefs {
	jboolean	lowerCheck;
	jboolean	upperCheck;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$sub_nonrefs	soot_jimple_toolkits_annotation_tags_ArrayCheckTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$object {
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$vtype _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_tags_ArrayCheckTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_tags_ArrayCheckTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_tags_ArrayCheckTag_H_ */
